powered by
This function calculates the indicator value for pesticide leaching from a soil
ind_pesticide_leaching(D_PESTICIDE)
The evaluated score for the soil function to minimize pesticide leaching. A numeric value between 0 and 1.
The fraction of pesticide leached compared to the worst case scenario
ind_pesticide_leaching(D_PESTICIDE = 0.7) ind_pesticide_leaching(D_PESTICIDE = c(0.4,0.6,0.8,1))
Run the code above in your browser using DataLab