ind_waterstressindex: Calculate the Water Stress Index
Description
This function calculates the risk for yield depression due to drought, an excess of water or a combination of both. The WSI is calculated by calc_waterstressindex
Usage
ind_waterstressindex(D_WSI)
Value
The evaluated score for the soil function to resist drought or wetness stress by crops. A numeric value between 0 and 1.
Arguments
D_WSI
(numeric) The value of WSI calculated by calc_waterstressindex