calc_makkink: Add Makkink correction factors and crop cover to crop rotation table
Description
This function adds Makkink correction factors for ET and crop cover to the crop rotation table
Usage
calc_makkink(B_LU_BRP)
Value
A datatable with the crop dependent Makkink correction factor per month.
Output is a single data.table with for each B_LU_BRP code the monthly correction factor.
Columns of the data.table are: crop_makkink, month, year, mcf and crop_cover.