Learn R Programming

OBIC (version 4.2.1)

calc_organic_carbon: Calculate amount of organic carbon

Description

This function calculates the amount of organic carbon in the soil

Usage

calc_organic_carbon(A_SOM_LOI, D_BDS, D_RD)

Value

The total amount of Carbon in the soil (kg C / ha). A numeric value.

Arguments

A_SOM_LOI

(numeric) The percentage organic matter in the soil

D_BDS

(numeric) The bulk density of the soil

D_RD

(numeric) The root depth of the crop

Examples

Run this code
calc_organic_carbon(A_SOM_LOI = 4.3, D_BDS = 1100, D_RD = 0.2)
calc_organic_carbon(A_SOM_LOI = c(1,4.3), D_BDS = c(1100,1300), D_RD = c(0.2,0.6))

Run the code above in your browser using DataLab