powered by
This function calculates the amount of organic carbon in the soil
calc_organic_carbon(A_SOM_LOI, D_BDS, D_RD)
The total amount of Carbon in the soil (kg C / ha). A numeric value.
(numeric) The percentage organic matter in the soil
(numeric) The bulk density of the soil
(numeric) The root depth of the crop
calc_organic_carbon(A_SOM_LOI = 4.3, D_BDS = 1100, D_RD = 0.2) calc_organic_carbon(A_SOM_LOI = c(1,4.3), D_BDS = c(1100,1300), D_RD = c(0.2,0.6))
Run the code above in your browser using DataLab