Learn R Programming

OBIC (version 4.2.1)

ind_pesticide_leaching: Calculate an indicator score for pesticide leaching

Description

This function calculates the indicator value for pesticide leaching from a soil

Usage

ind_pesticide_leaching(D_PESTICIDE)

Value

The evaluated score for the soil function to minimize pesticide leaching. A numeric value between 0 and 1.

Arguments

D_PESTICIDE

The fraction of pesticide leached compared to the worst case scenario

Examples

Run this code
ind_pesticide_leaching(D_PESTICIDE = 0.7)
ind_pesticide_leaching(D_PESTICIDE  = c(0.4,0.6,0.8,1))
 

Run the code above in your browser using DataLab